#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-quickcheck
version:              0.11.1
visibility:           public
id:                   tasty-quickcheck-0.11.1-I1ieovmGVbl2rDwurGh6aR
key:                  tasty-quickcheck-0.11.1-I1ieovmGVbl2rDwurGh6aR
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.

category:             Testing
abi:                  64d9224754620a9d62887bd950bfd15d
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-quickcheck-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.11.1-I1ieovmGVbl2rDwurGh6aR
depends:
    QuickCheck-2.15.0.1-3mU9ZiusQQy5d3HGk3bpZl base-4.18.2.1
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
    tasty-1.5.3-9Ly5zOHTOKj1qAbC4RsUQH

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

